@@ -1,15 +1,11 @@
-#=======================================================================
+# Code in the PDF::API2::Basic::PDF namespace was originally copied from the
+# Text::PDF distribution.
 #
-#   THIS IS A REUSED PERL MODULE, FOR PROPER LICENCING TERMS SEE BELOW:
+# Copyright Martin Hosken <Martin_Hosken@sil.org>
 #
-#   Copyright Martin Hosken <Martin_Hosken@sil.org>
-#
-#   No warranty or expression of effectiveness, least of all regarding
-#   anyone's safety, is implied in this software or documentation.
-#
-#   This specific module is licensed under the Perl Artistic License.
-#
-#=======================================================================
+# Martin Hosken's code may be used under the terms of the MIT license.
+# Subsequent versions of the code have the same license as PDF::API2.
+
 package PDF::API2::Basic::PDF::Dict;
 
 use base 'PDF::API2::Basic::PDF::Objind';
@@ -17,7 +13,7 @@ use base 'PDF::API2::Basic::PDF::Objind';
 use strict;
 no warnings qw[ deprecated recursion uninitialized ];
 
-our $VERSION = '2.038'; # VERSION
+our $VERSION = '2.047'; # VERSION
 
 our $mincache = 16 * 1024 * 1024;
 
@@ -28,7 +24,7 @@ use PDF::API2::Basic::PDF::Name;
 
 =head1 NAME
 
-PDF::API2::Basic::PDF::Dict - PDF Dictionaries and Streams. Inherits from L<PDF::Objind>
+PDF::API2::Basic::PDF::Dict - Low-level dictionary and stream objects
 
 =head1 INSTANCE VARIABLES
 
@@ -58,7 +54,7 @@ source PDF the stream starts.
 =cut
 
 sub new {
-    my ($class) = @_;
+    my $class = shift();
     $class = ref($class) if ref($class);
 
     my $self = $class->SUPER::new(@_);
